marktools.BendAfter
===================

.. abjad-lineage:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter

.. autoclass:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.bend_amount
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.attach
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__repr__
   :noindex:

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__str__
   :noindex:
